==> autokreso-mailchimp-0.1.0-0751b2.tar: test/Entity/MailingList/Member/LocationTest.php <==
<?php
namespace AkTest\Mailchimp\Entity\MailingList\Member;

use Ak\Mailchimp\Entity\MailingList\Member\Location;
use AkTest\Mailchimp\AbstractTestCase;
use Zend\Hydrator\HydratorInterface;
use Zend\Hydrator\HydratorPluginManager;
use Zend\ServiceManager\PluginManagerInterface;

/**
 * Class MailingListStatsTest
 *
 * @package AkTest\Mailchimp\Entity\MailingList\Member
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/mailchimp
 */
final class LocationTest extends AbstractTestCase
{
    public function testHydratorCanExchangeEntity()
    {
        $container = $this->getContainer();
        /** @var PluginManagerInterface $hydrators */
        $hydrators = $container->get(HydratorPluginManager::class);
        /** @var HydratorInterface $hydrator */
        $hydrator = $hydrators->get(Location::class);

        $data = [
            'latitude' => 45.4353,
            'longitude' => 23.32423,
            'gmtoff' => 2,
            'dstoff' => 1,
            'country_code' => 'hr',
            'timezone' => '+0200',
        ];

        /** @var Location $location */
        $location = $hydrator->hydrate($data, new Location());

        $this->assertEquals($data['latitude'], $location->getLatitude());
        $this->assertEquals($data['longitude'], $location->getLongitude());
        $this->assertEquals($data['gmtoff'], $location->getGmtoff());
        $this->assertEquals($data['dstoff'], $location->getDstoff());
        $this->assertEquals($data['country_code'], $location->getCountryCode());
        $this->assertEquals($data['timezone'], $location->getTimezone());

        $extracted = $hydrator->extract($location);

        $this->assertEquals($data, $extracted);
    }
}

==> autokreso-mailchimp-0.1.4-44891a.tar: test/Entity/MailingList/Member/LocationTest.php <==
<?php
namespace AkTest\Mailchimp\Entity\MailingList\Member;

use Ak\Mailchimp\Entity\MailingList\Member\Location;
use AkTest\Mailchimp\AbstractTestCase;
use Laminas\Hydrator\HydratorInterface;
use Laminas\Hydrator\HydratorPluginManager;
use Laminas\ServiceManager\PluginManagerInterface;

/**
 * Class MailingListStatsTest
 *
 * @package AkTest\Mailchimp\Entity\MailingList\Member
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/mailchimp
 */
final class LocationTest extends AbstractTestCase
{
    public function testHydratorCanExchangeEntity()
    {
        $container = $this->getContainer();
        /** @var PluginManagerInterface $hydrators */
        $hydrators = $container->get(HydratorPluginManager::class);
        /** @var HydratorInterface $hydrator */
        $hydrator = $hydrators->get(Location::class);

        $data = [
            'latitude' => 45.4353,
            'longitude' => 23.32423,
            'gmtoff' => 2,
            'dstoff' => 1,
            'country_code' => 'hr',
            'timezone' => '+0200',
        ];

        /** @var Location $location */
        $location = $hydrator->hydrate($data, new Location());

        $this->assertEquals($data['latitude'], $location->getLatitude());
        $this->assertEquals($data['longitude'], $location->getLongitude());
        $this->assertEquals($data['gmtoff'], $location->getGmtoff());
        $this->assertEquals($data['dstoff'], $location->getDstoff());
        $this->assertEquals($data['country_code'], $location->getCountryCode());
        $this->assertEquals($data['timezone'], $location->getTimezone());

        $extracted = $hydrator->extract($location);

        $this->assertEquals($data, $extracted);
    }
}
